@@ -801,16 +801,41 @@ class HdDB:
         try:
             query = f'SELECT * FROM "{org}__{db}".hd_tables WHERE id = ?'
             result = self.execute(query, [tbl]).fetchdf()
+            logger.info("--------------------------------")
+            logger.info("Query result:")
+            logger.info(result)
+            logger.info("--------------------------------")
+
             data = result.to_dict(orient="records")
-            nrow, ncol, tbl_name = (
-                data[0]["nrow"],
-                data[0]["ncol"],
-                data[0]["id"],
-            )
-            return {"nrow": nrow, "ncol": ncol, "tbl_name": tbl_name}
+            logger.info("Data dictionary:")
+            logger.info(data)
+            logger.info("--------------------------------")
+
+            if not data:
+                raise QueryError(f"Table '{tbl}' not found in database '{org}__{db}'")
+
+            # Obtener los valores con fallback a valores por defecto
+            row_data = data[0]
+            metadata = {
+                "nrow": float(row_data.get("tb_n_rows", row_data.get("nrow", 0))),
+                "ncol": float(row_data.get("tb_n_columns", row_data.get("ncol", 0))),
+                "tbl_name": row_data.get("id", tbl),
+                "label": row_data.get("label", tbl),
+                "description": row_data.get("description"),
+                "created_at": row_data.get("tb_created_at"),
+                "updated_at": row_data.get("tb_updated_at"),
+                "magnitude": float(row_data.get("tb_magnitude", 0)),
+            }
+
+            logger.info("Final metadata:")
+            logger.info(metadata)
+            logger.info("--------------------------------")
+
+            return metadata
+
         except duckdb.Error as e:
-            logger.error(f"Error fetching metadata from hd_fields: {e}")
-            raise QueryError(f"Error fetching metadata from hd_fields: {e}")
+            logger.error(f"Error fetching metadata from hd_tables: {e}")
+            raise QueryError(f"Error fetching metadata from hd_tables: {e}")
 
     @attach_motherduck
     def update_records(
